@@ -1,5 +1,5 @@
 package App::CSE::Lucy::Highlight::Highlighter;
-$App::CSE::Lucy::Highlight::Highlighter::VERSION = '0.011';
+$App::CSE::Lucy::Highlight::Highlighter::VERSION = '0.012';
 use base qw/Lucy::Highlight::Highlighter/;
 
 use strict;
@@ -53,7 +53,7 @@ sub highlight{
   my $cse = $cse{ $self };
 
   if( $cse->interactive() ){
-    return $cse->colorizer->colored($text , 'white bold');
+    return $cse->colorizer->colored($text , 'yellow on_black');
   }else{
     return '[>'.$text.'<]';
   }
